==> gpxview_0.9.0.tar.gz: gpxview-0.9.0/src/config.h <==
/*
 * Copyright (C) 2008-2009 Till Harbaum <till@harbaum.org>.
 *
 * This file is part of GPXView.
 *
 * GPXView is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GPXView is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GPXView.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONFIG_H
#define CONFIG_H

#define TAG_STATE  GTK_STATE_PRELIGHT

#ifndef USE_MAEMO
#define DEFAULT_IMAGE_PATH       "/tmp/gpxview/"
#define DEFAULT_MMPOI_PATH       "gpxview_poi.db"
#define DEFAULT_GARMIN_PATH      "garmin_overridden.gpx"
#define DEFAULT_FIELDNOTES_PATH  "geocache_visits_%s.txt"
#else
#if MAEMO_VERSION_MAJOR < 5
/* internal memory card */
#define DEFAULT_IMAGE_PATH       "/media/mmc2/gpxview/"
#else
#define DEFAULT_IMAGE_PATH       "/home/user/.gpxview/"
#endif
#define DEFAULT_MMPOI_PATH       "MyDocs/.documents/Maps/gpxview_poi.db"
#define DEFAULT_GARMIN_PATH      "MyDocs/.documents/garmin_overridden.gpx"
#define DEFAULT_FIELDNOTES_PATH  "MyDocs/.documents/geocache_visits_%s.txt"
#endif

#define DEFAULT_IMAGE_PATH_HOME  ".gpxview/"

#define LOCALEDIR PREFIX "/share/locale"
#define PACKAGE   "gpxview"

// for osm-gps-map:
#define USE_CAIRO
#define ENABLE_OSD
#define OSD_BALLOON
#define OSD_SCALE
#define OSD_CROSSHAIR
#define OSD_NAV

#ifdef USE_MAEMO
#define BIG_BALLOONS
#define BALLOON_AREA_WIDTH        (390)
#define BALLOON_AREA_HEIGHT       (105)
#define BALLOON_CORNER_RADIUS     (20)
#define OSD_FONT_SIZE             (28.0)
#define OSD_DIAMETER              (60)
#define OSD_SCALE_FONT_SIZE       (20.0)
#define OSD_COORDINATES_FONT_SIZE (20.0)

#endif

#define OSD_COORDINATES
#include <libintl.h>
#define OSD_COORDINATES_CHR_N  gettext("N")
#define OSD_COORDINATES_CHR_S  gettext("S")
#define OSD_COORDINATES_CHR_E  gettext("E")
#define OSD_COORDINATES_CHR_W  gettext("W")

/* only maemo devices up to version 4 have a fullscreen button */
#ifdef USE_MAEMO
#include <hildon/hildon-defines.h>
#if (MAEMO_VERSION_MAJOR < 5)
#define OSM_GPS_MAP_KEY_FULLSCREEN  HILDON_HARDKEY_FULLSCREEN
#else
#define OSM_GPS_MAP_KEY_FULLSCREEN  'f'
#endif
#define OSM_GPS_MAP_KEY_ZOOMIN      HILDON_HARDKEY_INCREASE
#define OSM_GPS_MAP_KEY_ZOOMOUT     HILDON_HARDKEY_DECREASE
#else
#define OSM_GPS_MAP_KEY_FULLSCREEN  GDK_F11
#define OSM_GPS_MAP_KEY_ZOOMIN      '+'
#define OSM_GPS_MAP_KEY_ZOOMOUT     '-'
#endif

#define OSM_GPS_MAP_KEY_UP          GDK_Up
#define OSM_GPS_MAP_KEY_DOWN        GDK_Down
#define OSM_GPS_MAP_KEY_LEFT        GDK_Left
#define OSM_GPS_MAP_KEY_RIGHT       GDK_Right

/* specify OSD colors explicitely. Otherwise gtk default */
/* colors are used. fremantle always uses gtk defaults */
#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
#define OSD_COLOR_BG         1, 1, 1         // white background
#define OSD_COLOR            0.5, 0.5, 1     // light blue border and controls
#define OSD_COLOR_DISABLED   0.8, 0.8, 0.8   // light grey disabled controls
#define OSD_SHADOW_ENABLE
#else
#define OSD_Y  -10
#endif

#define OSD_DOUBLE_BUFFER    // render osd/map together offscreen
#define OSD_GPS_BUTTON       // display a GPS button
#define OSD_NO_DPAD          // no direction arrows (map is panned)
#define OSD_SOURCE_SEL       // display source selection tab

#endif // CONFIG_H

==> gpxview_0.9.6.tar.gz: gpxview-0.9.6/src/config.h <==
/*
 * Copyright (C) 2008-2009 Till Harbaum <till@harbaum.org>.
 *
 * This file is part of GPXView.
 *
 * GPXView is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GPXView is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GPXView.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONFIG_H
#define CONFIG_H

#define TAG_STATE  GTK_STATE_PRELIGHT

#ifndef USE_MAEMO
#define DEFAULT_IMAGE_PATH       "/tmp/gpxview/"
#define DEFAULT_MMPOI_PATH       "gpxview_poi.db"
#define DEFAULT_GARMIN_PATH      "garmin_overridden.gpx"
#define DEFAULT_FIELDNOTES_PATH  "geocache_visits_%s.txt"
#else
#if MAEMO_VERSION_MAJOR < 5
/* internal memory card */
#define DEFAULT_IMAGE_PATH       "/media/mmc2/gpxview/"
#else
#define DEFAULT_IMAGE_PATH       "/home/user/.gpxview/"
#endif
#define DEFAULT_MMPOI_PATH       "MyDocs/.documents/Maps/gpxview_poi.db"
#define DEFAULT_GARMIN_PATH      "MyDocs/.documents/garmin_overridden.gpx"
#define DEFAULT_FIELDNOTES_PATH  "MyDocs/.documents/geocache_visits_%s.txt"
#endif

#define DEFAULT_IMAGE_PATH_HOME  ".gpxview/"

#define LOCALEDIR PREFIX "/share/locale"
#define PACKAGE   "gpxview"

// for osm-gps-map:
#define USE_CAIRO
#define ENABLE_OSD
#define OSD_BALLOON
#define OSD_SCALE
#define OSD_CROSSHAIR
#define OSD_NAV

#ifdef USE_MAEMO
#define BIG_BALLOONS
#define BALLOON_AREA_WIDTH        (390)
#define BALLOON_AREA_HEIGHT       (105)
#define BALLOON_CORNER_RADIUS     (20)
#define OSD_FONT_SIZE             (28.0)
#define OSD_DIAMETER              (60)
#define OSD_SCALE_FONT_SIZE       (20.0)
#define OSD_COORDINATES_FONT_SIZE (20.0)

#endif

#define OSD_COORDINATES
#include <libintl.h>
#define OSD_COORDINATES_CHR_N  gettext("N")
#define OSD_COORDINATES_CHR_S  gettext("S")
#define OSD_COORDINATES_CHR_E  gettext("E")
#define OSD_COORDINATES_CHR_W  gettext("W")

#define _(a) gettext(a)

/* only maemo devices up to version 4 have a fullscreen button */
#ifdef USE_MAEMO
#include <hildon/hildon-defines.h>
#if (MAEMO_VERSION_MAJOR < 5)
#define MAP_KEY_FULLSCREEN  HILDON_HARDKEY_FULLSCREEN
#else
#define MAP_KEY_FULLSCREEN  'f'
#endif
#define MAP_KEY_ZOOMIN      HILDON_HARDKEY_INCREASE
#define MAP_KEY_ZOOMOUT     HILDON_HARDKEY_DECREASE
#else
#define MAP_KEY_FULLSCREEN  GDK_F11
#define MAP_KEY_ZOOMIN      '+'
#define MAP_KEY_ZOOMOUT     '-'
#endif

#define MAP_KEY_UP          GDK_Up
#define MAP_KEY_DOWN        GDK_Down
#define MAP_KEY_LEFT        GDK_Left
#define MAP_KEY_RIGHT       GDK_Right

/* specify OSD colors explicitely. Otherwise gtk default */
/* colors are used. fremantle always uses gtk defaults */
#if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
#define OSD_COLOR_BG         1, 1, 1, 1      // white background
#define OSD_COLOR            0.5, 0.5, 1     // light blue border and controls
#define OSD_COLOR_DISABLED   0.8, 0.8, 0.8   // light grey disabled controls
#define OSD_SHADOW_ENABLE
#else
#define OSD_Y  -10
#endif

#define OSD_DOUBLE_BUFFER    // render osd/map together offscreen
#define OSD_GPS_BUTTON       // display a GPS button
#define OSD_NO_DPAD          // no direction arrows (map is panned)
#define OSD_SOURCE_SEL       // display source selection tab
#define OSD_DOUBLEPIXEL      // allow pixel doubling from OSD

#endif // CONFIG_H
